JSON¶
JSON
Any JSON value: annotate a module's input or output with it to say "data,
of any shape" (shape {}). A plain Any, object or no annotation
says the value may have no JSON form at all (an opaque field).
JSON
Any JSON value: annotate a module's input or output with it to say "data,
of any shape" (shape {}). A plain Any, object or no annotation
says the value may have no JSON form at all (an opaque field).