load_plugin¶
load_plugin(path)
A plugin from a Python file that defines plugin (an
Plugin). Loading runs the file: load only code you trust. A file is
read again when it changed (reload after editing it).
load_plugin(path)
A plugin from a Python file that defines plugin (an
Plugin). Loading runs the file: load only code you trust. A file is
read again when it changed (reload after editing it).